@@ -65,6 +65,42 @@ def format_index(body: Json) -> Json:
         result["cacheEnabled"] = body["cacheEnabled"]
     if "legacyPolygons" in body:
         result["legacyPolygons"] = body["legacyPolygons"]
+    if "estimates" in body:
+        result["estimates"] = body["estimates"]
+    if "analyzer" in body:
+        result["analyzer"] = body["analyzer"]
+    if "cleanupIntervalStep" in body:
+        result["cleanup_interval_step"] = body["cleanupIntervalStep"]
+        if "commitIntervalMsec" in body:
+            result["commit_interval_msec"] = body["commitIntervalMsec"]
+    if "consolidationIntervalMsec" in body:
+        result["consolidation_interval_msec"] = body["consolidationIntervalMsec"]
+    if "consolidationPolicy" in body:
+        result["consolidation_policy"] = format_view_consolidation_policy(
+            body["consolidationPolicy"]
+        )
+    if "features" in body:
+        result["features"] = body["features"]
+    if "includeAllFields" in body:
+        result["include_all_fields"] = body["includeAllFields"]
+    if "primarySort" in body:
+        result["primary_sort"] = body["primarySort"]
+    if "searchField" in body:
+        result["search_field"] = body["searchField"]
+    if "trackListPositions" in body:
+        result["track_list_positions"] = body["trackListPositions"]
+    if "version" in body:
+        result["version"] = body["version"]
+    if "cache" in body:
+        result["cache"] = body["cache"]
+    if "primaryKeyCache" in body:
+        result["primaryKeyCache"] = body["primaryKeyCache"]
+    if "writebufferIdle" in body:
+        result["writebuffer_idle"] = body["writebufferIdle"]
+    if "writebufferActive" in body:
+        result["writebuffer_active"] = body["writebufferActive"]
+    if "writebufferSizeMax" in body:
+        result["writebuffer_max_size"] = body["writebufferSizeMax"]
 
     return verify_format(body, result)
 
@@ -227,6 +263,8 @@ def format_collection(body: Json) -> Json:
             }
             for cv in body["computedValues"]
         ]
+    if "internalValidatorType" in body:
+        result["internal_validator_type"] = body["internalValidatorType"]
 
     return verify_format(body, result)
 
@@ -318,6 +356,10 @@ def format_aql_query(body: Json) -> Json:
         result["stream"] = body["stream"]
     if "user" in body:
         result["user"] = body["user"]
+
+    # New in 3.11
+    if "peakMemoryUsage" in body:
+        result["peak_memory_usage"] = body["peakMemoryUsage"]
     return verify_format(body, result)
 
 
@@ -393,6 +435,10 @@ def format_server_status(body: Json) -> Json:
     """
     result: Json = {}
 
+    if "agency" in body:
+        result["agency"] = body["agency"]
+    if "coordinator" in body:
+        result["coordinator"] = body["coordinator"]
     if "foxxApi" in body:
         result["foxx_api"] = body["foxxApi"]
     if "host" in body:
@@ -794,6 +840,10 @@ def format_view_link(body: Json) -> Json:
         result["track_list_positions"] = body["trackListPositions"]
     if "storeValues" in body:
         result["store_values"] = body["storeValues"]
+    if "primaryKeyCache" in body:
+        result["primaryKeyCache"] = body["primaryKeyCache"]
+    if "companies" in body:
+        result["companies"] = body["companies"]
 
     return verify_format(body, result)
 
@@ -882,13 +932,19 @@ def format_view(body: Json) -> Json:
     if "writebufferSizeMax" in body:
         result["writebuffer_max_size"] = body["writebufferSizeMax"]
     if "links" in body:
-        result["links"] = {
-            name: format_view_link(link) for name, link in body["links"].items()
-        }
+        result["links"] = body["links"]
     if "indexes" in body:
-        result["indexes"] = {
-            name: format_view_index(idx) for name, idx in body["indexes"].items()
-        }
+        result["indexes"] = body["indexes"]
+
+    # Introduced in 3.9.6 EE
+    if "primaryKeyCache" in body:
+        result["primaryKeyCache"] = body["primaryKeyCache"]
+    if "primarySortCache" in body:
+        result["primarySortCache"] = body["primarySortCache"]
+
+    # Introduced in 3.12 EE
+    if "optimizeTopK" in body:
+        result["optimizeTopK"] = body["optimizeTopK"]
 
     return verify_format(body, result)
 
@@ -985,6 +1041,9 @@ def format_backup(body: Json) -> Json:
     if "nrPiecesPresent" in body:
         result["pieces_present"] = body["nrPiecesPresent"]
 
+    if "countIncludesFilesOnly" in body:
+        result["count_includes_files_only"] = body["countIncludesFilesOnly"]
+
     return verify_format(body, result)
 
 
@@ -1135,6 +1194,14 @@ def format_pregel_job_data(body: Json) -> Json:
     # The detail element was introduced in 3.10
     if "detail" in body:
         result["detail"] = body["detail"]
+    if "database" in body:
+        result["database"] = body["database"]
+    if "masterContext" in body:
+        result["master_context"] = body["masterContext"]
+    if "parallelism" in body:
+        result["parallelism"] = body["parallelism"]
+    if "useMemoryMaps" in body:
+        result["use_memory_maps"] = body["useMemoryMaps"]
 
     return verify_format(body, result)
 
@@ -1177,12 +1244,18 @@ def format_graph_properties(body: Json) -> Json:
     }
     if "isSmart" in body:
         result["smart"] = body["isSmart"]
+    if "isSatellite" in body:
+        result["is_satellite"] = body["isSatellite"]
     if "smartGraphAttribute" in body:
         result["smart_field"] = body["smartGraphAttribute"]
     if "numberOfShards" in body:
         result["shard_count"] = body["numberOfShards"]
     if "replicationFactor" in body:
         result["replication_factor"] = body["replicationFactor"]
+    if "minReplicationFactor" in body:
+        result["min_replication_factor"] = body["minReplicationFactor"]
+    if "writeConcern" in body:
+        result["write_concern"] = body["writeConcern"]
 
     return verify_format(body, result)
 
